pub struct AstStr(/* private fields */);Expand description
Ast string
Implementations
Sourceimpl AstStr
impl AstStr
Sourcepub fn new(repr: impl Into<AstStrRepr>) -> Self
pub fn new(repr: impl Into<AstStrRepr>) -> Self
Creates a new ast string without any associated input range
Sourcepub fn from_input(input: Substr) -> Self
pub fn from_input(input: Substr) -> Self
Creates a new ast string from an input range
Sourcepub fn replace(&mut self, repr: impl Into<AstStrRepr>)
pub fn replace(&mut self, repr: impl Into<AstStrRepr>)
Replaces this ast string
Sourcepub fn repr(&self) -> &AstStrRepr
pub fn repr(&self) -> &AstStrRepr
Returns the inner representation of this string
Sourcepub fn count_newlines(&self) -> usize
pub fn count_newlines(&self) -> usize
Returns the number of newlines in this string
Sourcepub fn has_newlines(&self) -> bool
pub fn has_newlines(&self) -> bool
Returns if this string has newlines